@@ -417,7 +417,7 @@ class FeatureStore():
 
         return response.json()['freq']
 
-    def get_timeseries(self, feature, entity=None, from_date=None, to_date=None, freq=None):
+    def get_timeseries(self, feature, entity=None, from_date=None, to_date=None, freq=None, time_travel=None):
         """Gets feature timeseries from feature store.
 
         Parameters
@@ -434,6 +434,8 @@ class FeatureStore():
             A datetime string.
         freq : str, optional
             A freq string using pandas offset aliases, https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html#offset-aliases, e.g. '1H'.
+        time_travel : str, optional
+            A freq string using pandas offset aliases, https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html#offset-aliases, e.g. '-3H'.
 
         Returns
         -------
@@ -468,6 +470,7 @@ class FeatureStore():
             'from_date': pd.Timestamp(from_date).isoformat(),
             'to_date': pd.Timestamp(to_date).isoformat(),
             'freq': freq,
+            'time_travel': time_travel,
             'entity': ','.join(entity) if entity else None
         }
         response = requests.get(
